package cn.minestar.agriculture.mapper;

import java.util.List;

import cn.minestar.agriculture.entity.WxMiniStarRecord;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author www.minestar.cn/
 * @date 2021-08-10
 */
public interface WxMiniStarRecordMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public WxMiniStarRecord selectWxMiniStarRecordById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param wxMiniStarRecord 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<WxMiniStarRecord> selectWxMiniStarRecordList(WxMiniStarRecord wxMiniStarRecord);

    /**
     * 新增【请填写功能名称】
     * 
     * @param wxMiniStarRecord 【请填写功能名称】
     * @return 结果
     */
    public int insertWxMiniStarRecord(WxMiniStarRecord wxMiniStarRecord);

    /**
     * 修改【请填写功能名称】
     * 
     * @param wxMiniStarRecord 【请填写功能名称】
     * @return 结果
     */
    public int updateWxMiniStarRecord(WxMiniStarRecord wxMiniStarRecord);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteWxMiniStarRecordById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteWxMiniStarRecordByIds(Long[] ids);
}
